==> wget-1.4.0.tar.gz: wget-1.4.0/src/init.h <==
/* Declarations for reading/parsing the initialization file.
   Copyright (C) 1995,96  Hrvoje Niksic
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */


#ifndef INIT_H
#define INIT_H

#define ISODIGIT(x) ((x) >= '0' && (x) <= '7')

/* Command enumeration. */
typedef enum {
   NONE, ACCEPT, ADDHOSTDIR, ALWAYSREST, BACKUPS, BASEHREF,
   CACHE, CONVERTLINKS, DEBUG_, DIRMODE, DIRPREFIX, DIRSTRUCT, DOMAINS,
   EXCLUDEDIRECTORIES, FILEPREFIX, FOLLOWFTP, FORCEHTML, FTPPROXY, GLOB,
   HEADER, HTTPPASSWD, HTTPPROXY, HTTPUSER, INPUT, KILLLONGER, LOGFILE,
   LOGIN, MIRROR, NOCLOBBER, NOPARENT, NOPROXY,
   NUMTRIES, OUTPUTDOCUMENT, PASSWD, PREFIXFILES, QUIET, QUOTA, RECLEVEL,
   RECURSIVE, REJECT, RELATIVEONLY, REMOVELISTING, ROBOTS, SAVEHEADERS,
   SERVERRESPONSE, SIMPLEHOSTCHECK, SPANHOSTS, SPIDER, TIMEOUT,
   TIMESTAMPING, USEPROXY, USERAGENT, VERBOSE,
   LAST
} cmdid;

/* Command struct */
struct cmd {
   char *name;
   cmdid id;
};

cmdid comind(const struct cmd *, const char *);
char *init_path(void);
void run_wgetrc(const char *);
void initialize(void);
int parse_line(const char *, char **, char **);
int setval(const char *, const char *);
int onoff(const char *);
int setonoff(int *, const char *, const char *);
int setnuminf(int *, const char *, const char *, int);
int setquota(long *, const char *, const char *);
void defaults(void);
int myatoi(const char *);
int getperms(const char *);
void cleanup(void);

#endif /* INIT_H */

==> wget-1.4.1.tar.gz: wget-1.4.1/src/init.h <==
/* Declarations for reading/parsing the initialization file.
   Copyright (C) 1995,96  Hrvoje Niksic
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */


#ifndef INIT_H
#define INIT_H

#define ISODIGIT(x) ((x) >= '0' && (x) <= '7')

/* Print definitions for default style. */
#define DOTS_IN_LINE 50
#define DOT_BYTES 1024
#define DOT_SPACING 10

/* Command enumeration. */
typedef enum {
   NONE, ACCEPT, ADDHOSTDIR, ALWAYSREST, BACKUPS, BASEHREF,
   CACHE, CONVERTLINKS, DEBUG_, DIRMODE, DIRPREFIX, DIRSTRUCT, DOMAINS,
   DOTBYTES, DOTSINLINE, DOTSPACING, DOTSTYLE,
   EXCLUDEDIRECTORIES, FILEPREFIX, FOLLOWFTP, FORCEHTML, FTPPROXY, GLOB,
   HEADER, HTMLIFY, HTTPPASSWD, HTTPPROXY, HTTPUSER,
   INPUT, INCLUDEDIRECTORIES,
   KILLLONGER, LOGFILE, LOGIN, MIRROR, NOCLOBBER, NOPARENT, NOPROXY,
   NUMTRIES, OUTPUTDOCUMENT, PASSWD, PREFIXFILES, QUIET, QUOTA, RECLEVEL,
   RECURSIVE, REJECT, RELATIVEONLY, REMOVELISTING, ROBOTS, SAVEHEADERS,
   SERVERRESPONSE, SIMPLEHOSTCHECK, SPANHOSTS, SPIDER, TIMEOUT,
   TIMESTAMPING, USEPROXY, USERAGENT, VERBOSE,
   LAST
} cmdid;

/* Command struct */
struct cmd {
   char *name;
   cmdid id;
};

cmdid comind(const struct cmd *, const char *);
char *init_path(void);
void run_wgetrc(const char *);
void initialize(void);
int parse_line(const char *, char **, char **);
int setval(const char *, const char *);
int onoff(const char *);
int setonoff(int *, const char *, const char *);
int setnuminf(int *, const char *, const char *);
int setbytes(long *, const char *, const char *);
void defaults(void);
int myatoi(const char *);
int getperms(const char *);
void cleanup(void);

#endif /* INIT_H */
